@@ -8,6 +8,8 @@ from os import path
 def json_parameters_function():
     def inner(func):
         def wrapper(json_object):
+            if json_object is str:
+                json_object = JsonObject.load(json_object)
             p = {}
             for v in func.__code__.co_varnames:
                 if v in json_object.__dict__:
